@@ -4,6 +4,10 @@ describe 'GH-1572', site: true, stdio: true do
   example do
     FileUtils.mkdir_p('content')
 
+    allow_any_instance_of(Nanoc::Core::BinaryCompiledContentCache)
+      .to receive(:use_clonefile?)
+      .and_return(false)
+
     File.write('content/repro.jpg', '<data>')
     File.chmod(0o400, 'content/repro.jpg')
     expect(File.stat('content/repro.jpg').mode).to eq(0o100400)
