@@ -45,7 +45,11 @@ class Nanoc::CLI::Commands::PruneTest < Nanoc::TestCase
       File.write('output2/foo.html', 'this is a foo.')
       File.write('output2/index.html', 'this is a index.')
 
-      Nanoc::CLI.run %w[prune --yes]
+      io = capturing_stdio do
+        Nanoc::CLI.run %w[prune --yes]
+      end
+
+      assert_match %r{^\s+delete  output2/foo\.html$}, io[:stdout]
 
       assert File.file?('output2/index.html')
       refute File.file?('output2/foo.html')
@@ -69,8 +73,8 @@ class Nanoc::CLI::Commands::PruneTest < Nanoc::TestCase
         Nanoc::CLI.run %w[prune --dry-run]
       end
 
-      assert_match %r{^\s+delete\s+\(dry run\) .*/output2/index\.html$}, io[:stdout]
-      assert_match %r{^\s+delete\s+\(dry run\) .*/output2/foo\.html$}, io[:stdout]
+      assert_match %r{^\s+delete  \(dry run\) output2/index\.html$}, io[:stdout]
+      assert_match %r{^\s+delete  \(dry run\) output2/foo\.html$}, io[:stdout]
 
       assert File.file?('output2/index.html')
       assert File.file?('output2/foo.html')
